# -*- coding: utf-8 -*-
# Description:
# Setup for the OSP debsecan Server
#
# Authors:
# Jan-Oliver Wagner <Jan-Oliver.Wagner@greenbone.net>
#
# Copyright:
# Copyright (C) 2015 Greenbone Networks GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

from ospd.ospd import OSPDaemon
from ospd.misc import main as daemon_main
from ospd_debsecan import __version__

# For running the debsecan command:
import subprocess

OSPD_DEBSECAN_DESC = """
This scanner runs the tool 'debsecan' on the local host where the scanner is installed.

This tool is available for Debian GNU/Linux systems and can create a list of vulnerabilities the present system is subject to.
The tool goes beyond a simple match about which package updates are missing.
It rather does an online query to learn about software packages where security problems are identified, but not yet been finally processed to become a security update.

Further details about the tool are vailable on the debsecan homepage:

http://www.enyo.de/fw/software/debsecan/

For executing debsecan a low privileged user account is sufficient.
"""

class OSPDdebsecan(OSPDaemon):

    """ Class for ospd-debsecan daemon. """

    def __init__(self, certfile, keyfile, cafile):
        """ Initializes the ospd-debsecan daemon's internal data. """
        super(OSPDdebsecan, self).__init__(certfile=certfile, keyfile=keyfile,
                                            cafile=cafile)
        self.server_version = __version__
        self.scanner_info['name'] = 'debsecan'
        self.scanner_info['version'] = 'depends on the local installation at the target host'
        self.scanner_info['description'] = OSPD_DEBSECAN_DESC

    def check(self):
        """ Checks that debsecan command line tool is found and is executable. """
        return True

    def exec_scan(self, scan_id, target):
        """ Starts the debsecan scanner for scan_id scan. """

        # run the debsecan command
        try:
            result = subprocess.check_output(["debsecan"])
        except:
            self.add_scan_error(scan_id, host=target,
              value="A problem occurred trying to execute 'debsecan'.")
            return

        # parse the output of the debsecan command and create
        # respective alarms
        for line in result.split("\n"):
            words = line.split()
            if words.__len__() > 2 and words[0].split("-")[0] == "CVE":
                self.add_scan_alarm(scan_id, host=target, name=words[0],
                                    value=line)

def main():
    """ OSP debsecan main function. """
    daemon_main('OSPD - debsecan wrapper', OSPDdebsecan)
